@@ -10,18 +10,31 @@ def list_workflows(las_client: Client, max_results=None, next_token=None):
     return las_client.list_workflows(max_results=max_results, next_token=next_token)
 
 
-def create_workflow(las_client: Client, specification_path, error_config, **optional_args):
+def create_workflow(las_client: Client, specification_path, error_config_path, completed_config_path, **optional_args):
     specification = json.loads(pathlib.Path(specification_path).read_text())
-    error_config = json.loads(error_config) if error_config else None
-    return las_client.create_workflow(specification, error_config=error_config, **optional_args)
+    error_config = json.loads(pathlib.Path(error_config_path).read_text()) if error_config_path else None
+    completed_config = json.loads(pathlib.Path(completed_config_path).read_text()) if completed_config_path else None
+    return las_client.create_workflow(
+        specification,
+        error_config=error_config,
+        completed_config=completed_config,
+        **optional_args,
+    )
 
 
 def get_workflow(las_client: Client, workflow_id):
     return las_client.get_workflow(workflow_id)
 
 
-def update_workflow(las_client: Client, workflow_id, **optional_args):
-    return las_client.update_workflow(workflow_id, **optional_args)
+def update_workflow(las_client: Client, workflow_id, error_config_path, completed_config_path, **optional_args):
+    error_config = json.loads(pathlib.Path(error_config_path).read_text()) if error_config_path else None
+    completed_config = json.loads(pathlib.Path(completed_config_path).read_text()) if completed_config_path else None
+    return las_client.update_workflow(
+        workflow_id,
+        error_config=error_config,
+        completed_config=completed_config,
+        **optional_args,
+    )
 
 
 def execute_workflow(las_client: Client, workflow_id, path):
@@ -44,6 +57,14 @@ def delete_workflow(las_client: Client, workflow_id):
     return las_client.delete_workflow(workflow_id)
 
 
+def get_workflow_execution(las_client: Client, workflow_id, execution_id):
+    return las_client.get_workflow_execution(workflow_id, execution_id)
+
+
+def update_workflow_execution(las_client: Client, workflow_id, execution_id, next_transition_id):
+    return las_client.update_workflow_execution(workflow_id, execution_id, next_transition_id)
+
+
 def delete_workflow_execution(las_client: Client, workflow_id, execution_id):
     return las_client.delete_workflow_execution(workflow_id, execution_id)
 
@@ -61,13 +82,22 @@ def create_workflows_parser(subparsers):
     create_workflow_parser.add_argument('specification_path')
     create_workflow_parser.add_argument('--name')
     create_workflow_parser.add_argument('--description')
-    create_workflow_parser.add_argument('--error-config', type=str)
+    create_workflow_parser.add_argument('--error-config-path', help='path to the error configuration for the workflow')
+    create_workflow_parser.add_argument(
+        '--completed-config-path',
+        help='path to the execution completed configuration for the workflow',
+    )
     create_workflow_parser.set_defaults(cmd=create_workflow)
 
     update_workflow_parser = subparsers.add_parser('update')
     update_workflow_parser.add_argument('workflow_id')
     update_workflow_parser.add_argument('--name', type=nullable, default=NotProvided)
     update_workflow_parser.add_argument('--description', type=nullable, default=NotProvided)
+    update_workflow_parser.add_argument('--error-config-path', help='path to the error configuration for the workflow')
+    update_workflow_parser.add_argument(
+        '--completed-config-path',
+        help='path to the execution completed configuration for the workflow',
+    )
     update_workflow_parser.set_defaults(cmd=update_workflow)
 
     execute_workflow_parser = subparsers.add_parser('execute')
@@ -92,6 +122,20 @@ def create_workflows_parser(subparsers):
     delete_workflow_parser.add_argument('workflow_id')
     delete_workflow_parser.set_defaults(cmd=delete_workflow)
 
+    get_workflow_execution_parser = subparsers.add_parser('get-execution')
+    get_workflow_execution_parser.add_argument('workflow_id')
+    get_workflow_execution_parser.add_argument('execution_id')
+    get_workflow_execution_parser.set_defaults(cmd=get_workflow_execution)
+
+    update_workflow_execution_parser = subparsers.add_parser('update-execution')
+    update_workflow_execution_parser.add_argument('workflow_id')
+    update_workflow_execution_parser.add_argument('execution_id')
+    update_workflow_execution_parser.add_argument(
+        'next_transition_id',
+        help='use las:transition:commons-failed to end an execution',
+    )
+    update_workflow_execution_parser.set_defaults(cmd=update_workflow_execution)
+
     delete_workflow_execution_parser = subparsers.add_parser('delete-execution')
     delete_workflow_execution_parser.add_argument('workflow_id')
     delete_workflow_execution_parser.add_argument('execution_id')
